using System;
using System.Collections.Generic;
using System.Linq;
using Microsoft.Xna.Framework;
using Microsoft.Xna.Framework.Audio;
using Microsoft.Xna.Framework.Content;
using Microsoft.Xna.Framework.GamerServices;
using Microsoft.Xna.Framework.Graphics;
using Microsoft.Xna.Framework.Input;
using Microsoft.Xna.Framework.Media;

/*
 * Bitmap Font Display Library
 * by Brian MacIntosh
 * 
 * All code used in this example ('Game1.cs', 'BitmapFont.cs', 'BitmapFontAnimation.cs')
 * may be used freely in commecial and non-commercial projects.
 * 
 * 'PacMania.png' image was created by Scraggle (Craig McFarlane).
 * For more information on this image, and additional images, see this post:
 * http://forum.thegamecreators.com/?m=forum_view&t=74431&b=4
 */

namespace BitmapFontExample
{
    public class Game1 : Game
    {
        GraphicsDeviceManager graphics;
        SpriteBatch spriteBatch;

        bool pressed = false;

        /// <summary>
        /// A bitmap font object that can be used to draw text to the screen.
        /// </summary>
        Thunderfish.BitmapFont font;

        /// <summary>
        /// An animated string object that uses the font.
        /// </summary>
        Thunderfish.BitmapFontAnimation pressStart;

        public Game1()
        {
            graphics = new GraphicsDeviceManager(this);
            Content.RootDirectory = "Content";
        }

        protected override void LoadContent()
        {
            // Create a new SpriteBatch, which can be used to draw textures.
            spriteBatch = new SpriteBatch(GraphicsDevice);

            font = new Thunderfish.BitmapFont("PacMania", false);
            font.LoadContent(Content);

            pressStart = new Thunderfish.BounceText(font, "Press Start", TimeSpan.FromSeconds(0.5), TimeSpan.FromSeconds(0.1), -100);
        }

        protected override void Update(GameTime gameTime)
        {
            // Allows the game to exit
            if (GamePad.GetState(PlayerIndex.One).Buttons.Back == ButtonState.Pressed)
                this.Exit();

            //Update the animated string
            pressStart.Update(gameTime);

            //Trigger the animated string
            if (Keyboard.GetState().IsKeyDown(Keys.Space))
            {
                if (!pressed)
                {
                    pressed = true;
                    pressStart.Animate();
                }
            }
            else
            {
                pressed = false;
            }

            base.Update(gameTime);
        }

        /// <summary>
        /// This is called when the game should draw itself.
        /// </summary>
        /// <param name="gameTime">Provides a snapshot of timing values.</param>
        protected override void Draw(GameTime gameTime)
        {
            GraphicsDevice.Clear(Color.Black);

            spriteBatch.Begin();

            //Draw the animated string
            pressStart.Draw(
                spriteBatch,
                new Vector2(100),
                1f,
                Thunderfish.BitmapFont.Justification.LEFT,
                Color.White);

            //Draw some text using the font
            font.DrawString(
                spriteBatch,
                "Static Text!",
                new Vector2(100, 200),
                1f,
                Thunderfish.BitmapFont.Justification.LEFT,
                Color.White);

            spriteBatch.End();

            base.Draw(gameTime);
        }
    }
}
